@@ -1,11 +1,10 @@
-#' @title Terminator that stops according to the clock time
+#' @title Clock Time Terminator
 #'
 #' @name mlr_terminators_clock_time
 #' @include Terminator.R
 #'
 #' @description
-#' Class to terminate the optimization after a fixed time point has been reached
-#' (as reported by [Sys.time()]).
+#' Class to terminate the optimization after a fixed time point has been reached (as reported by [Sys.time()]).
 #'
 #' @templateVar id clock_time
 #' @template section_dictionary_terminator
@@ -13,11 +12,13 @@
 #' @section Parameters:
 #' \describe{
 #' \item{`stop_time`}{`POSIXct(1)`\cr
-#' Terminator stops after this point in time.}
+#'   Terminator stops after this point in time.}
 #' }
 #'
 #' @family Terminator
+#'
 #' @template param_archive
+#'
 #' @export
 #' @examples
 #' stop_time = as.POSIXct("2030-01-01 00:00:00")
@@ -25,19 +26,26 @@
 TerminatorClockTime = R6Class("TerminatorClockTime",
   inherit = Terminator,
   public = list(
+
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
       param_set = ps(
         stop_time = p_uty(tags = "required", custom_check = function(x) check_class(x, "POSIXct"))
       )
-      super$initialize(param_set = param_set, properties = c("single-crit", "multi-crit"))
-      self$unit = "seconds"
+      super$initialize(
+        param_set = param_set,
+        properties = c("single-crit", "multi-crit"),
+        unit = "seconds",
+        label = "Clock Time",
+        man = "bbotk::mlr_terminators_clock_time"
+      )
     },
 
     #' @description
     #' Is `TRUE` iff the termination criterion is positive, and `FALSE`
     #' otherwise.
+    #'
     #' @return `logical(1)`.
     is_terminated = function(archive) {
       assert_r6(archive, "Archive")
@@ -47,10 +55,8 @@ TerminatorClockTime = R6Class("TerminatorClockTime",
 
   private = list(
     .status = function(archive) {
-      max_steps = as.integer(ceiling(difftime(self$param_set$values$stop_time,
-        archive$start_time, units = "secs")))
-      current_steps = as.integer(difftime(Sys.time(), archive$start_time),
-        units = "secs")
+      max_steps = as.integer(ceiling(difftime(self$param_set$values$stop_time, archive$start_time, units = "secs")))
+      current_steps = as.integer(difftime(Sys.time(), archive$start_time, units = "secs"))
       c("max_steps" = max_steps, "current_steps" = current_steps)
     }
   )
